@@ -280,13 +280,13 @@ let transcode =
 module Transcode = struct
     let more w s =
         match Lazy.force w with
-        | Z -> Lazy.lazy_from_val Cf_seq.Z, w
+        | Z -> Cf_seq.nil, w
         | P (_, _) -> drain w, flush w
         | Q f -> let w = lazy (f (Some s)) in drain w, flush w
     
     let last w =
         match Lazy.force w with
-        | Z -> Lazy.lazy_from_val Cf_seq.Z
+        | Z -> Cf_seq.nil
         | P (_, _) -> drain w
         | Q f -> drain (lazy (f None))
 end
