@@ -242,7 +242,7 @@ value cf_ip4_proto_getsockopt_uchar
    (const Cf_socket_option_context_t* contextPtr)
 {
     u_char optval;
-    size_t optlen;
+    socklen_t optlen;
     
     memset(&optval, 0, sizeof optval);
     optlen = sizeof optval;
@@ -269,7 +269,7 @@ value cf_ip4_proto_getsockopt_addr
    (const Cf_socket_option_context_t* contextPtr)
 {
     struct in_addr optval;
-    size_t optlen;
+    socklen_t optlen;
     
     memset(&optval, 0, sizeof optval);
     optlen = sizeof optval;
@@ -293,7 +293,7 @@ value cf_ip4_proto_getsockopt_mreq
     CAMLparam0();
     CAMLlocal3(multiaddrVal, interfaceVal, resultVal);
     struct ip_mreq optval;
-    size_t optlen;
+    socklen_t optlen;
     
     memset(&optval, 0, sizeof optval);
     optlen = sizeof optval;
