@@ -87,7 +87,7 @@ static long cf_ip6_proto_sockaddr_hash(value sxVal)
 
     sin6Ptr = &Cf_socket_sockaddrx_val(in6, sxVal)->sx_sockaddr_in6;
     result = ntohs(sin6Ptr->sin6_port);
-    p = (long*) &sin6Ptr->sin6_addr;
+    p = (unsigned long*) &sin6Ptr->sin6_addr;
     for (i = 0; i < 4; ++i) result ^= ntohl(p[i]);
     result ^= sin6Ptr->sin6_scope_id;
     
@@ -224,7 +224,7 @@ value cf_ip6_proto_getsockopt_mreq
     CAMLparam0();
     CAMLlocal2(multiaddrVal, resultVal);
     struct ipv6_mreq optval;
-    size_t optlen;
+    socklen_t optlen;
     
     memset(&optval, 0, sizeof optval);
     optlen = sizeof optval;
