@@ -81,12 +81,12 @@ module type T = sig
             val mutable archivers_: 'archiver list
             val mutable limit_: Priority.t            
 
-            method virtual private event_: 'level -> string -> 'event
+            method private virtual event: 'level -> string -> 'event
 
             method setlimit: 'level -> unit
             method enabled: 'level -> bool
             
-            method private put_:
+            method private put:
                 'a 'b. 'level -> ('event -> 'b) ->
                 ('a, unit, string, 'b) format4 -> 'a
         end
@@ -124,17 +124,17 @@ module Create(P: Cf_ordered.Total_T) : (T with module Priority = P) = struct
             val mutable archivers_: 'archiver list = archivers
             val mutable limit_ = prioritizer#code limit
         
-            method virtual private event_: 'level -> string -> 'event
+            method private virtual event: 'level -> string -> 'event
 
             method setlimit limit = limit_ <- prioritizer#code limit
             method enabled limit = prioritizer#code limit >= limit_
             
-            method private put_:
+            method private put:
                 'a 'b. 'level -> ('event -> 'b) ->
                 ('a, unit, string, 'b) format4 -> 'a
                 = fun level cont ->
                     let f message =
-                        let e = self#event_ level message in
+                        let e = self#event level message in
                         if self#enabled level then
                             List.iter (fun j -> j#emit e) archivers_;
                         cont e
@@ -219,22 +219,22 @@ class virtual ['archiver] basic_agent prioritizer limit archivers =
         inherit ['archiver] Basic.agent prioritizer limit archivers
 
         method invalid: 'a 'b. ('a, unit, string, 'b) format4 -> 'a =
-            self#put_ `Invalid (fun x -> invalid_arg x#message)
+            self#put `Invalid (fun x -> invalid_arg x#message)
 
         method fail: 'a 'b. ('a, unit, string, 'b) format4 -> 'a =
-            self#put_ `Fail (fun x -> failwith x#message)
+            self#put `Fail (fun x -> failwith x#message)
         
         method error: 'a. ('a, unit, string, unit) format4 -> 'a =
-            self#put_ `Error ignore
+            self#put `Error ignore
         
         method warn: 'a. ('a, unit, string, unit) format4 -> 'a =
-            self#put_ `Warn ignore
+            self#put `Warn ignore
         
         method info: 'a. ('a, unit, string, unit) format4 -> 'a =
-            self#put_ `Info ignore
+            self#put `Info ignore
         
         method debug: 'a. ('a, unit, string, bool) format4 -> 'a =
-            self#put_ `Debug (fun _ -> true)
+            self#put `Debug (fun _ -> true)
     end
 
 let basic_prioritizer = new basic_prioritizer
@@ -250,7 +250,7 @@ class basic_stdio_agent archiver =
         inherit [Basic.level_t Basic.event basic_channel_archiver] basic_agent
             basic_prioritizer `Warn [archiver]
         
-        method private event_ = new Basic.event basic_prioritizer
+        method private event = new Basic.event basic_prioritizer
     end
 
 let stdout = new basic_stdio_agent basic_stdout_archiver
