@@ -125,10 +125,10 @@ module type T = sig
             *)
             val mutable limit_: Priority.t            
 
-            (** Define the private [event_] method to construct an event object
+            (** Define the private [event] method to construct an event object
                 with a priority level and a message text.
             *)
-            method virtual private event_: 'level -> string -> 'event
+            method private virtual event: 'level -> string -> 'event
 
             (** Use [a#setlimit v] to set the minimum priority code to the
                 code corresponding to the priority level [v].
@@ -143,9 +143,9 @@ module type T = sig
             
             (** Use this method in level-specific methods of the derived class
                 for constructing events and putting them to archivers.  Use
-                [super#put_ v c] to construct a function that takes a format
+                [super#put v c] to construct a function that takes a format
                 string (and arguments thereby specified) and, if [self#enabled
-                v] returns [true] then calls [self#event_ v m] (where [m] is
+                v] returns [true] then calls [self#event v m] (where [m] is
                 the message text given to the continuation provided to
                 [Printf.kprintf]), iterates on [archivers_] invoking the
                 [emit] method for each one with the constructed event, and
@@ -153,7 +153,7 @@ module type T = sig
                 returned by [c] is returned by the method when invoked with
                 a format string (and associated arguments).
             *)
-            method private put_:
+            method private put:
                 'a 'b. 'level -> ('event -> 'b) ->
                 ('a, unit, string, 'b) format4 -> 'a
         end
