@@ -30,13 +30,21 @@
   OF THE POSSIBILITY OF SUCH DAMAGE. 
  *---------------------------------------------------------------------------*)
 
+(**)
+let jout = Cf_journal.stdout
+(**)
+
 type ('s, 'a) t = 's Cf_seq.t -> ('a * 's Cf_seq.t) option
 
 exception Error
 
 let nil _ = None
 
-let err f s = raise (f s)
+let err_aux_ _ = Error
+
+let err ?(f = err_aux_) () s = raise (f s)
+
+let req ?f p s = match p s with None -> err ?f () s | x -> x
 
 let fin s =
     match Lazy.force s with
@@ -59,13 +67,6 @@ let rec altz pz s =
         | None -> altz tl s
         | v -> v
 
-let req_aux_ _ = Error
-
-let req ?(f = req_aux_) p s =
-    match p s with
-    | None -> err f s
-    | x -> x
-
 let sat f s =
     match Lazy.force s with
     | Cf_seq.P (i, tl) when f i -> Some (i, tl)
@@ -113,12 +114,15 @@ module type X = sig
         constraint 'z = 'i * 'c
         constraint 'c = 'x #cursor
 
-    val weave: c:('i #cursor as 'c) -> 'i Cf_seq.t -> ('i * 'c) Cf_seq.t
+    exception Error of int
 
+    val err: ?f:(('i * 'c) Cf_seq.t -> exn) -> unit -> ('c, 'i, 'o) t
+    val req: ?f:(('i * 'c) Cf_seq.t -> exn) -> ('c, 'i, 'o) t -> ('c, 'i, 'o) t
     val sat: ('i -> bool) -> ('c, 'i, 'i) t
     val tok: ('i -> 'o option) -> ('c, 'i, 'o) t
     val lit: string -> 'o -> ('c, char, 'o) t
     
+    val weave: c:('i #cursor as 'c) -> 'i Cf_seq.t -> ('i * 'c) Cf_seq.t
     val unfold: ('c, 'i, 'o) t -> ('i * 'c) Cf_seq.t -> ('o * 'c) Cf_seq.t
 end
 
@@ -127,15 +131,19 @@ module X: X = struct
         constraint 'z = 'i * 'c
         constraint 'c = 'x #cursor
     
-    let rec weave ~c s =
-        lazy begin
-            match Lazy.force s with
-            | Cf_seq.P (hd, tl) ->
-                Cf_seq.P ((hd, c), weave ~c:(c#advance hd) tl)
-            | Cf_seq.Z ->
-                Cf_seq.Z
-        end
+    exception Error of int
     
+    let err_aux_ s =
+        Error begin
+            match Lazy.force s with
+            | Cf_seq.Z -> (-1)
+            | Cf_seq.P ((_, c), _) -> c#position
+        end
+
+    let err ?(f = err_aux_) () s = raise (f s)
+
+    let req ?f p s = match p s with None -> err ?f () s | x -> x
+
     let sat f s =
         match Lazy.force s with
         | Cf_seq.P ((i, _), tl) when f i -> Some (i, tl)
@@ -163,6 +171,15 @@ module X: X = struct
         in
         fun s ->
             loop 0 s
+    
+    let rec weave ~c s =
+        lazy begin
+            match Lazy.force s with
+            | Cf_seq.P (hd, tl) ->
+                Cf_seq.P ((hd, c), weave ~c:(c#advance hd) tl)
+            | Cf_seq.Z ->
+                Cf_seq.Z
+        end
 
     let rec unfold p s =
         lazy begin
@@ -208,20 +225,18 @@ module Op = struct
         match Lazy.force seq with
         | Cf_seq.Z ->
             begin
-                let z = Lazy.lazy_from_val Cf_seq.Z in
-                match q (X.unfold p z) with
+                match q (X.unfold p Cf_seq.nil) with
                 | None -> None
-                | Some (x, _) -> Some (x, z)
+                | Some (x, _) -> Some (x, Cf_seq.nil)
             end
         | Cf_seq.P ((_, c0), _) ->
-            let n0 = c0#position in
             match q (X.unfold p seq) with
             | None -> None
             | Some (x, seq') ->
                 let seq'' =
                     match Lazy.force seq' with
                     | Cf_seq.Z ->
-                        Lazy.lazy_from_val Cf_seq.Z
+                        Cf_seq.nil
                     | Cf_seq.P ((_, c1), _) ->
                         Cf_seq.shift (c1#position - c0#position) seq
                 in
@@ -246,18 +261,21 @@ let rec optmap f p s =
         | None -> optmap f p s
         | Some y -> Some (y, s)
 
-let rec to_extended_aux_ n z s =
-    if z == s then
+let rec to_extended_aux_ n fin s =
+    let z = Lazy.force s in
+    if fin == z then
         n
     else
-        match Lazy.force s with
-        | Cf_seq.P (_, tl) -> to_extended_aux_ (succ n) z tl
+        match z with
+        | Cf_seq.P (c, tl) -> to_extended_aux_ (succ n) fin tl
         | Cf_seq.Z -> assert (not true); n
 
 let to_extended p s =
     let s0 = Cf_seq.first s in
     match p s0 with
-    | Some (x, s1) -> Some (x, Cf_seq.shift (to_extended_aux_ 0 s1 s0) s)
+    | Some (x, s1) ->
+        let fin = Lazy.force s1 in
+        Some (x, Cf_seq.shift (to_extended_aux_ 0 fin s0) s)
     | None -> None
 
 let of_extended c p s =
