@@ -51,11 +51,16 @@ exception Error
 (** A parser that never recognizes any input, i.e. it always returns [None]. *)
 val nil: ('i, 'o) t
 
-(** Use [err f] to compose parser that applies the input token stream to the
-    optional function [f] to obtain an Objective Caml exception, then raises
-    the exception.  The default function simply raises [Error].
+(** Use [err ?f ()] to compose parser that applies the input token stream to
+    the optional function [f] to obtain an Objective Caml exception, then
+    raises the exception.  The default function simply raises [Error].
 *)
-val err: ('i Cf_seq.t -> exn) -> ('i, 'x) t
+val err: ?f:('i Cf_seq.t -> exn) -> unit -> ('i, 'x) t
+
+(** Use [req f p] to create a parser that requires the input stream to match
+    the parser [p] or it will be passed to the parser [err f] instead.
+*)
+val req: ?f:('i Cf_seq.t -> exn) -> ('i, 'o) t -> ('i, 'o) t
 
 (** A parser that produces the unit value when it recognizes the end of the
     input token sequence.
@@ -76,11 +81,6 @@ val alt: ('i, 'o) t list -> ('i, 'o) t
 *)
 val altz: ('i, 'o) t Cf_seq.t -> ('i, 'o) t
 
-(** Use [req f p] to create a parser that requires the input stream to match
-    the parser [p] or it will be passed to the parser [err f] instead.
-*)
-val req: ?f:('i Cf_seq.t -> exn) -> ('i, 'o) t -> ('i, 'o) t
-
 (** Use [sat f] to create a parser that recognizes, shifts and reduces input
     tokens for which the satisfier function [f] returns [true].
 *)
@@ -131,10 +131,20 @@ module X: sig
         constraint 'z = 'i * 'c
         constraint 'c = 'x #cursor
 
-    (** Use [weave ~c i] with an initial cursor [c] and an input sequence [i]
-        to create an input sequence with accompanying cursor.
+    (** Generic parser error with one positional parameter. *)
+    exception Error of int
+
+    (** Use [err ?f ()] to compose parser that applies the input token stream
+        to the optional function [f] to obtain an Objective Caml exception,
+        then raises the exception.  The default function simply raises [Error].
     *)
-    val weave: c:('i #cursor as 'c) -> 'i Cf_seq.t -> ('i * 'c) Cf_seq.t
+    val err: ?f:(('i * 'c) Cf_seq.t -> exn) -> unit -> ('c, 'i, 'o) t
+
+    (** Use [req ?f p] to create a parser that requires the input stream to
+        match the parser [p] or it will be passed to the parser [err ?f ()]
+        instead.
+    *)
+    val req: ?f:(('i * 'c) Cf_seq.t -> exn) -> ('c, 'i, 'o) t -> ('c, 'i, 'o) t
 
     (** Use [sat f] to create a parser that recognizes, shifts and reduces
         input tokens for which the satisfier function [f] returns [true].
@@ -152,6 +162,11 @@ module X: sig
     *)
     val lit: string -> 'o -> ('c, char, 'o) t
 
+    (** Use [weave ~c i] with an initial cursor [c] and an input sequence [i]
+        to create an input sequence with accompanying cursor.
+    *)
+    val weave: c:('i #cursor as 'c) -> 'i Cf_seq.t -> ('i * 'c) Cf_seq.t
+
     (** Use [unfold p i] to create a sequence of output values recognized by
         applying the input token sequence [i] to the parser [p] until no more
         input is recognized.  The cursor objects in the output sequence
