@@ -230,14 +230,14 @@ type 'a state_t = [
     | `Exception of exn
 ]
 
-class type ['a] event =
+class type ['s] event =
     object
         constraint 's = [> 'a state_t ]
         
         val mutable state_: 's
         val mutable put_: <get: 'a> Queue.t option
 
-        method private service_: t -> 's
+        method private service: t -> 's
         method private load_: t -> unit
         method private unload_: t -> unit
         
@@ -247,15 +247,15 @@ class type ['a] event =
         method get: 'a
     end
 
-class virtual ['a] core =
+class virtual ['s] core =
     object(self:'self)
-        constraint 'self = 'a #event
+        constraint 'self = 's #event
         val mutable state_ = `Unloaded
         val mutable put_ = None
 
-        method virtual private load_: t -> unit
-        method virtual private unload_: t -> unit
-        method virtual private service_: t -> 'outcome
+        method private virtual load_: t -> unit
+        method private virtual unload_: t -> unit
+        method private virtual service: t -> 'outcome
         
         method private put_ =
             match put_ with
@@ -265,7 +265,7 @@ class virtual ['a] core =
         method private callback_ p () =
             state_ <-
                 try
-                    match self#service_ p with
+                    match self#service p with
                     | (`Final _ as s) -> self#put_; self#unload_ p; s
                     | (`Exception _ as s) -> self#put_; s
                     | s -> s
@@ -320,25 +320,27 @@ class virtual ['a] core =
             | _ -> failwith "Cf_poll.get: unknown intermediate state."
     end
 
+type 'a file_state_t = [ 'a state_t | `Working of t * 'a ]
+type rwx_t = [ `R | `W | `X ]
+
 let fd_aux_of_mode_ =
     let r p = p.p_fd_r_aux_ in
     let w p = p.p_fd_w_aux_ in
     let x p = p.p_fd_w_aux_ in
     function `R -> r | `W -> w | `X -> x
 
-class virtual ['a] file rwx fd =
+class virtual ['s] file rwx fd =
     let aux = fd_aux_of_mode_ rwx in
     object(self:'self)
-        constraint 'self = 'a #core
-        constraint 's = [ 'a state_t | `Working of t * 'a ]
-        inherit ['a] core as super
+        constraint 's = [> 'a file_state_t ]
+        inherit ['s] core as super
 
-        method virtual private service_: t -> 's
+        method private virtual service: t -> 's
                 
         method private callback_ p () =
             state_ <-
                 try
-                    let s = self#service_ p in
+                    let s = self#service p in
                     begin
                         match s with
                         | (`Final _ as s) -> self#put_; self#unload_ p
@@ -401,10 +403,9 @@ class virtual ['a] file rwx fd =
             | _ -> super#get
     end
 
-class virtual ['a] signal (n: int) =
+class virtual ['s] signal (n: int) =
     object(self:'self)
-        constraint 'self = 'a #core
-        inherit ['a] core as super
+        inherit ['s] core as super
 
         method private load_ p =
             sig_register_ p n (super#callback_ p)
@@ -413,15 +414,14 @@ class virtual ['a] signal (n: int) =
             sig_unregister_ p n
     end
 
-class virtual ['a] time tm =
+class virtual ['s] time tm =
     object(self:'self)
-        constraint 'self = 'a #core
-        inherit ['a] core as super
+        inherit ['s] core as super
         
         val mutable epoch_: Cf_tai64n.t = tm
 
         method private callback_ p () =
-            state_ <- (try self#service_ p with e -> `Exception e);
+            state_ <- (try self#service p with e -> `Exception e);
             super#put_
 
         method private load_ p =
@@ -433,10 +433,9 @@ class virtual ['a] time tm =
             p.p_tm_heap_ <- Tm_heap.filter f p.p_tm_heap_
     end
 
-class virtual ['a] idle =
+class virtual ['s] idle =
     object(self:'self)
-        constraint 'self = 'a #core
-        inherit ['a] core as super
+        inherit ['s] core as super
         
         val mutable epoch_: Cf_tai64n.t option = None
         
@@ -444,7 +443,7 @@ class virtual ['a] idle =
             state_ <- begin
                 try
                     epoch_ <- Some now;
-                    self#service_ p
+                    self#service p
                 with
                 | e ->
                     epoch_ <- None;
