@@ -72,7 +72,7 @@ type 'a state_t = [
 (** The type of objects representing an I/O events that produce results of
     type ['a].
 *)
-class type virtual ['a] event =
+class type virtual ['s] event =
     object
         constraint 's = [> 'a state_t ]
         
@@ -84,12 +84,12 @@ class type virtual ['a] event =
         *)
         val mutable put_: <get: 'a> Queue.t option
 
-        (** The [self#service_ p] method is invoked in the cycle for the
+        (** The [self#service p] method is invoked in the cycle for the
             polling mux [p] when the event is ready to be serviced.  The method
             is virtual to accomodate specializations with intermediate state
             and event handling functionality.
         *)
-        method virtual private service_: t -> 's
+        method private virtual service: t -> 's
 
         (** The [self#load_ p] method is invoked in the [load] method to load
             the specialized event into the polling mux [p].
@@ -147,20 +147,28 @@ val create: unit -> t
 
 (** Use [cycle p] to wait until one or more of the I/O event objects loaded
     into the mux [p] is ready to be serviced, then service them (which includes
-    invoking their [obj#service_] method).  Returns [Last] if there are no more
+    invoking their [obj#service] method).  Returns [Last] if there are no more
     events loaded into the polling mux.  Otherwise, returns [More].
 *)
 val cycle: t -> more_t
 
+(** File events have a state that represents an intermediate result while the
+    event is still loaded in the mux.
+*)
+type 'a file_state_t = [ 'a state_t | `Working of t * 'a ]
+
+(** File events are associated with read, write or exception I/O events. *)
+type rwx_t = [ `R | `W | `X ]
+
 (** Use [inherit file rwx fd] to derive an I/O event object that waits for the
     file descriptor [fd] to be ready for reading, writing, or exception
     (according to the value of [rwx]).
 *)
-class virtual ['a] file:
-    [< `R | `W | `X ] -> Unix.file_descr ->
+class virtual ['s] file:
+    [< rwx_t ] -> Unix.file_descr ->
     object
-        inherit ['a] event
-        constraint 's = [ 'a state_t | `Working of t * 'a ]
+        inherit ['s] event
+        constraint 's = [> 'a file_state_t ]
         
         (** The method applied during the polling mux cycle whenever the file
             [fd] is ready for I/O.  If the value returned is [`Working
@@ -168,22 +176,26 @@ class virtual ['a] file:
             return [true] and [self#get] will return [v], but the event will
             remain loaded in the polling mux waiting for further events on the
             file descriptor [fd].
+            
+            Note: this type of this method is less general than its declaration
+            in the {!event} class type.  Its return type is constrained by
+            also including the [`Working of t * 'a] variant.
         *)
-        method virtual private service_: t -> 's
+        method private virtual service: t -> 's
     end
 
 (** Use [inherit signal n] to derive an I/O event that is serviced when the
     system delivers the signal [n].
 *)
-class virtual ['a] signal: int -> ['a] event
+class virtual ['s] signal: int -> ['s] event
 
 (** Use [inherit time epoch] to derive an I/O event that is serviced when the
     system clock reaches the time [epoch].
 *)
-class virtual ['a] time:
+class virtual ['s] time:
     Cf_tai64n.t ->
     object
-        inherit ['a] event
+        inherit ['s] event
         
         (** The epoch when the event is to be serviced. *)
         val mutable epoch_: Cf_tai64n.t
@@ -192,9 +204,9 @@ class virtual ['a] time:
 (** Use [inherit idle] to derive an I/O event that is serviced whenever a
     polling mux cycle would otherwise block for any non-zero length of time.
 *)
-class virtual ['a] idle:
+class virtual ['s] idle:
     object
-        inherit ['a] event
+        inherit ['s] event
 
         (** The epoch when the event is was serviced. *)
         val mutable epoch_: Cf_tai64n.t option
