@@ -51,7 +51,7 @@ end
 module Core(N: Node_T) = struct
     module N = N
 
-    (**)
+    (*
     type 'a ic_t = IC_o | IC_l of 'a N.t | IC_r of 'a N.t
     
     let invariant_key_compare_ x = function
@@ -139,7 +139,7 @@ module Core(N: Node_T) = struct
             (* try ignore (loop u); true with Failure _ as x -> false *)
     
     let invariant_aux_ = invariant_noprint_aux_
-    (**)
+    *)
     
     let nil = Z
     
@@ -248,7 +248,7 @@ module Core(N: Node_T) = struct
 
     let replace x u =
         let u = force_black_ (replace_aux_ x u) in
-        (**) assert (invariant_aux_ u); (**)
+        (* assert (invariant_aux_ u); *)
         u
     
     let l_repair_ = function
@@ -352,7 +352,7 @@ module Core(N: Node_T) = struct
     let delete k u =
         try
             let u, _, _ = extract_aux_ k u in
-            (**) assert (invariant_aux_ u); (**)
+            (* assert (invariant_aux_ u); *)
             u
         with
         | Not_found ->
@@ -496,7 +496,7 @@ module Core(N: Node_T) = struct
                 loop (lazy (Cf_seq.P (x, loop z b))) a
         in
         fun u ->
-            loop (Lazy.lazy_from_val Cf_seq.Z) u
+            loop Cf_seq.nil u
     
     let to_seq_decr =
         let rec loop z u =
@@ -508,7 +508,7 @@ module Core(N: Node_T) = struct
                 loop (lazy (Cf_seq.P (x, loop z a))) b
         in
         fun u ->
-            loop (Lazy.lazy_from_val Cf_seq.Z) u
+            loop Cf_seq.nil u
     
     let to_list_aux_ f =
         let rec loop acc = function
