@@ -1,7 +1,7 @@
 (*---------------------------------------------------------------------------*
   INTERFACE  cf_seq.mli
 
-  Copyright (c) 2002-2004, James H. Woodyatt
+  Copyright (c) 2002-2005, James H. Woodyatt
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -61,6 +61,9 @@ exception Empty
 
 (** {6 Functions} *)
 
+(** An empty sequence. *)
+val nil: 'a t
+
 (** Returns the first element in the sequence.  Raises [Empty] if the sequence
     has no elements, i.e. if the sequence is [Z].
 *)
@@ -80,6 +83,11 @@ val tail: 'a t -> 'a t
 *)
 val concat: 'a t -> 'a t -> 'a t
 
+(** [flatten a] returns the sequence of all the elements in the sequence of
+    sequences by concatenating them.
+*)
+val flatten: 'a t t -> 'a t
+
 (** [limit n s] returns the sequence of all the elements in [s], up to [n]
     elements in number and no more.  Raises [Invalid_argument] if [n < 0].
 *)
