@@ -130,13 +130,14 @@ module type T = sig
                 [opt].  Raises [Unix.Error] if there is an error.
             *)
             method getsockopt:
-                ('a, P.AF.tag_t, P.ST.tag_t) Cf_socket.sockopt_t -> 'a
+                'a. ('a, P.AF.tag_t, P.ST.tag_t) Cf_socket.sockopt_t -> 'a
 
             (** Use [obj#setsockopt opt v] to set the value of the socket
                 option [opt].  Raises [Unix.Error] if there is an error.
             *)
             method setsockopt:
-                ('a, P.AF.tag_t, P.ST.tag_t) Cf_socket.sockopt_t -> 'a -> unit
+                'a. ('a, P.AF.tag_t, P.ST.tag_t) Cf_socket.sockopt_t -> 'a ->
+                unit
         
             (** Use [self#getsockname] to get the locally bound endpoint
                 address of the socket.  Raises [Unix.Error] if there is an
