@@ -42,7 +42,7 @@ module ST = struct
 end
 
 module type T = sig
-    include Cf_sock_common.T
+    include Cf_sock_common.T with type P.ST.tag_t = [ `SOCK_DGRAM ]
 
     class endpoint:
         t ->
