@@ -45,7 +45,7 @@ module ST: Cf_socket.ST with type tag_t = [ `SOCK_DGRAM ]
     module type used for handling sockets of the [SOCK_DGRAM] socket type.
 *)
 module type T = sig
-    include Cf_sock_common.T
+    include Cf_sock_common.T with type P.ST.tag_t = [ `SOCK_DGRAM ]
 
     (** Use [new endpoint sock] to construct an object derived from
         {!Cf_sock_common.T.basic} that sports methods for sending data to one
