@@ -42,7 +42,7 @@ module ST = struct
 end
 
 module type T = sig
-    include Cf_sock_common.T
+    include Cf_sock_common.T with type P.ST.tag_t = [ `SOCK_STREAM ]
 
     class initiator:
         ?sock:t -> ?src:address_t -> address_t ->
