@@ -45,7 +45,7 @@ module ST: Cf_socket.ST with type tag_t = [ `SOCK_STREAM ]
     module type used for handling sockets of the [SOCK_STREAM] socket type.
 *)
 module type T = sig
-    include Cf_sock_common.T
+    include Cf_sock_common.T with type P.ST.tag_t = [ `SOCK_STREAM ]
 
     (** Use [new initiator ?sock ?src addr] to construct an object derived from
         {!Cf_sock_common.T.basic} that sports a method for connecting to a
