@@ -50,8 +50,8 @@ external createpair:
 external to_unix_file_descr:
     ('af,'st) t -> Unix.file_descr = "cf_socket_to_unix_file_descr"
 
-external domain_of_unit_sockaddr:
-    unit sockaddr_t -> unit domain_t = "cf_socket_domain_of_unit_sockaddr"
+external domain_of_sockaddr:
+    'af sockaddr_t -> 'af domain_t = "cf_socket_domain_of_sockaddr"
 
 external dup: (('af,'st) t as 'fd) -> 'fd = "cf_socket_dup"
 external dup2: (('af,'st) t as 'fd) -> 'fd -> unit = "cf_socket_dup2"
@@ -62,10 +62,10 @@ external getpeername: ('af, 'st) t -> 'af sockaddr_t = "cf_socket_getpeername"
 external bind: ('af,'st) t -> 'af sockaddr_t -> unit = "cf_socket_bind"
 external connect: ('af,'st) t -> 'af sockaddr_t -> unit = "cf_socket_connect"
 external listen:
-    ('af, ([<`SOCK_STREAM] as 'st)) t -> int -> unit =
+    ('af, ([< `SOCK_STREAM | `SOCK_SEQPACKET ] as 'st)) t -> int -> unit =
     "cf_socket_listen"
 external accept:
-    ('af, ([<`SOCK_STREAM] as 'st)) t -> ('af, 'st) t * 'af sockaddr_t =
+    ('af, ([ `SOCK_STREAM ] as 'st)) t -> ('af, 'st) t * 'af sockaddr_t =
     "cf_socket_accept"
 
 let shutdown sock cmd = Unix.shutdown (to_unix_file_descr sock) cmd
@@ -115,14 +115,14 @@ external send:
     ('af, 'st) t -> string -> int -> int -> msg_flags_t -> int =
     "cf_socket_send"
 external sendto:
-    ('af, ([<`SOCK_DGRAM] as 'st)) t -> string -> int -> int ->
+    ('af, ([ `SOCK_DGRAM ] as 'st)) t -> string -> int -> int ->
     msg_flags_t -> 'af sockaddr_t -> int =
     "cf_socket_sendto_bytecode" "cf_socket_sendto_native"
 external recv:
     ('af, 'st) t -> string -> int -> int -> msg_flags_t -> int =
     "cf_socket_recv"
 external recvfrom:
-    ('af, ([<`SOCK_DGRAM] as 'st)) t -> string -> int -> int ->
+    ('af, ([ `SOCK_DGRAM ] as 'st)) t -> string -> int -> int ->
     msg_flags_t -> int * 'af sockaddr_t = "cf_socket_recvfrom"
 
 module type AF = sig
