@@ -189,10 +189,10 @@ val createpair:
 *)
 val to_unix_file_descr: ('af,'st) t -> Unix.file_descr
 
-(** Use [domain_of_unit_sockaddr sa] to obtain the socket domain identifier
+(** Use [domain_of_sockaddr sa] to obtain the socket domain identifier
     associated with a socket address of unknown address family.
 *)
-val domain_of_unit_sockaddr: unit sockaddr_t -> unit domain_t
+val domain_of_sockaddr: 'af sockaddr_t -> 'af domain_t
 
 (** Use [dup sock] to create a duplicate of socket descriptor [sock].  Raises
     [Unix.Error] if there is an error.
@@ -232,13 +232,13 @@ val connect: ('af,'st) t -> 'af sockaddr_t -> unit
     connections with a backlog queue [n] spaces deep.  Raises [Unix.Error] if
     there is an error.
 *)
-val listen: ('af,([<`SOCK_STREAM] as 'st)) t -> int -> unit
+val listen: ('af,([< `SOCK_STREAM | `SOCK_SEQPACKET ] as 'st)) t -> int -> unit
 
 (** Use [accept sock] to accept a connected request on the listening socket
     [sock].  Returns a new socket descriptor and the socket address of the
     remote peer.  Raises [Unix.Error] if there is an error.
 *)
-val accept: ('af,([<`SOCK_STREAM] as 'st)) t -> ('af,'st) t * 'af sockaddr_t
+val accept: ('af,([ `SOCK_STREAM ] as 'st)) t -> ('af,'st) t * 'af sockaddr_t
 
 (** Use [shutdown sock cmd] to shutdown either sending or receiving (or both)
     on the socket [sock].  Raises [Unix.Error] if there is an error.
@@ -266,7 +266,7 @@ val send: ('af, 'st) t -> string -> int -> int -> msg_flags_t -> int
     substring of [buf].
 *)
 val sendto:
-    ('af, ([<`SOCK_DGRAM] as 'st)) t -> string -> int -> int ->
+    ('af, ([ `SOCK_DGRAM ] as 'st)) t -> string -> int -> int ->
     msg_flags_t -> 'af sockaddr_t -> int
 
 (** Use [recv sock buf pos len flags] to receive [len] octets into the string
@@ -285,7 +285,7 @@ val recv: ('af, 'st) t -> string -> int -> int -> msg_flags_t -> int
     [len] do not correspond to a valid substring of [buf].
 *)
 val recvfrom:
-    ('af, ([<`SOCK_DGRAM] as 'st)) t -> string -> int -> int ->
+    ('af, ([ `SOCK_DGRAM ] as 'st)) t -> string -> int -> int ->
     msg_flags_t -> int * 'af sockaddr_t
 
 (** Use [getsockopt sock opt] to obtain the value associated with the socket
