@@ -180,10 +180,10 @@ CAMLprim value cf_socket_to_unix_file_descr(value sockVal)
 }
 
 /*---
-external domain_of_unit_sockaddr:
-    unit sockaddr_t -> unit domain_t = "cf_socket_domain_of_unit_sockaddr"
+external domain_of_sockaddr:
+    'af sockaddr_t -> 'af domain_t = "cf_socket_domain_of_unit_sockaddr"
   ---*/
-CAMLprim value cf_socket_domain_of_unit_sockaddr(value sxVal)
+CAMLprim value cf_socket_domain_of_sockaddr(value sxVal)
 {
     CAMLparam1(sxVal);
     
@@ -272,7 +272,8 @@ CAMLprim value cf_socket_getsockname(value sockVal)
     const Cf_socket_t* sockPtr;
     struct sockaddr_storage ss;
     struct sockaddr* saPtr;
-    int addrLen, v;
+    socklen_t addrLen;
+    int v;
     
     sockPtr = Cf_socket_val(sockVal);
     saPtr = (struct sockaddr*) &ss;
@@ -296,7 +297,8 @@ CAMLprim value cf_socket_getpeername(value sockVal)
     const Cf_socket_t* sockPtr;
     struct sockaddr_storage ss;
     struct sockaddr* saPtr;
-    int addrLen, v;
+    socklen_t addrLen;
+    int v;
     
     sockPtr = Cf_socket_val(sockVal);
     saPtr = (struct sockaddr*) &ss;
@@ -349,7 +351,7 @@ CAMLprim void cf_socket_connect(value sockVal, value sxVal)
 #ifdef __APPLE__
     /* Mac OS X does not return the error in errno on non-blocking sockets */
     if (result && error == EINVAL) {
-        int optlen = sizeof error;
+        socklen_t optlen = sizeof error;
         getsockopt(sockPtr->s_fd, SOL_SOCKET, SO_ERROR, &error, &optlen);
     }
 #endif
@@ -392,7 +394,8 @@ CAMLprim value cf_socket_accept(value sockVal)
     const Cf_socket_t* sockPtr;
     struct sockaddr_storage ss;
     struct sockaddr* saPtr;
-    int addrLen, newFd, error;
+    socklen_t addrLen;
+    int newFd, error;
     
     sockPtr = Cf_socket_val(sockVal);
     saPtr = (struct sockaddr*) &ss;
@@ -535,7 +538,7 @@ CAMLprim value cf_socket_recvfrom
     int fd, pos, len, flags, result, error;
     struct sockaddr_storage ss;
     struct sockaddr* saPtr;
-    int addrLen;
+    socklen_t addrLen;
     
     sockPtr = Cf_socket_val(sockVal);
     dataPtr = String_val(dataVal);
@@ -612,33 +615,33 @@ value cf_socket_option_alloc(const Cf_socket_option_t* ptr)
 
 void cf_socket_getsockopt_guard
    (const Cf_socket_option_context_t* contextPtr, void* optval,
-    size_t* optlen)
+    socklen_t* optlen)
 {
     int result;
     
     result = getsockopt
        (contextPtr->xopt_fd, contextPtr->xopt_level, contextPtr->xopt_name,
-        optval, (int*) optlen);
+        optval, optlen);
     if (result) uerror("getsockopt", Nothing);
 }
 
 void cf_socket_setsockopt_guard
    (const Cf_socket_option_context_t* contextPtr, const void* optval,
-    size_t optlen)
+    socklen_t optlen)
 {
     int result;
-
+    
     result = setsockopt
        (contextPtr->xopt_fd, contextPtr->xopt_level, contextPtr->xopt_name,
-        optval, (int) optlen);
-    if (result) uerror("getsockopt", Nothing);
+        optval, optlen);
+    if (result) uerror("setsockopt", Nothing);
 }
 
 value cf_socket_getsockopt_bool
    (const Cf_socket_option_context_t* contextPtr)
 {
     int optval;
-    size_t optlen;
+    socklen_t optlen;
     
     optval = 0;
     optlen = sizeof optval;
@@ -659,7 +662,7 @@ value cf_socket_getsockopt_int
    (const Cf_socket_option_context_t* contextPtr)
 {
     int optval;
-    size_t optlen;
+    socklen_t optlen;
     
     optval = 0;
     optlen = sizeof optval;
@@ -680,7 +683,7 @@ value cf_socket_getsockopt_linger
    (const Cf_socket_option_context_t* contextPtr)
 {
     struct linger optval;
-    size_t optlen;
+    socklen_t optlen;
     value result;
     
     memset(&optval, 0, sizeof optval);
@@ -712,7 +715,7 @@ value cf_socket_getsockopt_timeout
    (const Cf_socket_option_context_t* contextPtr)
 {
     struct timeval optval;
-    size_t optlen;
+    socklen_t optlen;
     double dt;
     value result;
     
@@ -741,7 +744,7 @@ value cf_socket_getsockopt_error
    (const Cf_socket_option_context_t* contextPtr)
 {
     int optval;
-    size_t optlen;
+    socklen_t optlen;
     
     memset(&optval, 0, sizeof optval);
     optlen = sizeof optval;
@@ -800,10 +803,10 @@ CAMLprim void cf_socket_setsockopt(value sockVal, value optVal, value setVal)
     optPtrPtr = Cf_socket_option_val(optVal);
     setF = (*optPtrPtr)->opt_set;
     if (!setF) {
-	char failStr[80];
-	sprintf(failStr, "Cf_socket.getsockopt %s not implemented.",
-		(*optPtrPtr)->opt_name_str);
-	failwith(failStr);
+        char failStr[80];
+        sprintf(failStr, "Cf_socket.setsockopt %s not implemented.",
+            (*optPtrPtr)->opt_name_str);
+        failwith(failStr);
     }
     xopt.xopt_fd = sockPtr->s_fd;
     xopt.xopt_level = (*optPtrPtr)->opt_level;
