@@ -133,11 +133,11 @@ extern value cf_socket_option_alloc(const Cf_socket_option_t* ptr);
 
 extern void cf_socket_getsockopt_guard
    (const Cf_socket_option_context_t* contextPtr, void* optval,
-    size_t* optlen);
+    socklen_t* optlen);
 
 extern void cf_socket_setsockopt_guard
    (const Cf_socket_option_context_t* contextPtr, const void* optval,
-    size_t optlen);
+    socklen_t optlen);
 
 extern value cf_socket_getsockopt_bool
    (const Cf_socket_option_context_t* contextPtr);
