@@ -645,7 +645,7 @@ module T8 = struct
 
     let rparen = Cf_parser.alt [
         ?. ')';
-        Cf_parser.err (fun _ -> failwith "Expected ')'");
+        Cf_parser.err ~f:(fun _ -> failwith "Expected ')'") ();
     ]
     
     let number = Cf_parser.alt [
@@ -1028,28 +1028,28 @@ module T12 = struct
             let lhost, lport = laddr in
             let rhost, rport = raddr in
             if lhost <> rhost then
-                failwith "T11 error: host a#getpeername <> b#getsockname";
+                failwith "T12 error: host a#getpeername <> b#getsockname";
             if lport <> rport then
-                failwith "T11 error: port a#getpeername <> b#getsockname";
+                failwith "T12 error: port a#getpeername <> b#getsockname";
             let laddr = a#getsockname and raddr = b#getpeername in
             let lhost, lport = laddr in
             let rhost, rport = raddr in
             if lhost <> rhost then
-                failwith "T11 error: host a#getsockname <> b#getpeername";
+                failwith "T12 error: host a#getsockname <> b#getpeername";
             if lport <> rport then
-                failwith "T11 error: port a#getsockname <> b#getpeername";
+                failwith "T12 error: port a#getsockname <> b#getpeername";
             let tx = String.make len 'x' and rx = String.create len in
             let n = a#send tx 0 len in
-            if n <> len then failwith "T11 error: tx incomplete!";
+            if n <> len then failwith "T12 error: tx incomplete!";
             let n = b#recv rx 0 len in
-            if n <> len then failwith "T11 error: rx incomplete!";
-            if tx <> rx then failwith "T11 error: tx <> rx!";
+            if n <> len then failwith "T12 error: rx incomplete!";
+            if tx <> rx then failwith "T12 error: tx <> rx!";
             a#close;
             b#close;
             listen#close
         with
         | Unix.Unix_error (e, fn, _) ->
-            failwith (Printf.sprintf "T11 error: %s in %s.\n"
+            failwith (Printf.sprintf "T12 error: %s in %s.\n"
                 (Unix.error_message e) fn)
 end
 
@@ -1076,32 +1076,32 @@ module T13 = struct
             let lhost, lport, lscope = laddr in
             let rhost, rport, rscope = raddr in
             if lhost <> rhost then
-                failwith "T12 error: host a#getpeername <> b#getsockname";
+                failwith "T13 error: host a#getpeername <> b#getsockname";
             if lport <> rport then
-                failwith "T12 error: port a#getpeername <> b#getsockname";
+                failwith "T13 error: port a#getpeername <> b#getsockname";
             if lscope <> rscope then
-                failwith "T12 error: port a#getpeername <> b#getsockname";
+                failwith "T13 error: port a#getpeername <> b#getsockname";
             let laddr = a#getsockname and raddr = b#getpeername in
             let lhost, lport, lscope = laddr in
             let rhost, rport, rscope = raddr in
             if lhost <> rhost then
-                failwith "T12 error: host a#getsockname <> b#getpeername";
+                failwith "T13 error: host a#getsockname <> b#getpeername";
             if lport <> rport then
-                failwith "T12 error: port a#getsockname <> b#getpeername";
+                failwith "T13 error: port a#getsockname <> b#getpeername";
             if lscope <> rscope then
-                failwith "T12 error: port a#getsockname <> b#getpeername";
+                failwith "T13 error: port a#getsockname <> b#getpeername";
             let tx = String.make len 'x' and rx = String.create len in
             let n = a#send tx 0 len in
-            if n <> len then failwith "T12 error: tx incomplete!";
+            if n <> len then failwith "T13 error: tx incomplete!";
             let n = b#recv rx 0 len in
-            if n <> len then failwith "T12 error: rx incomplete!";
-            if tx <> rx then failwith "T12 error: tx <> rx!";
+            if n <> len then failwith "T13 error: rx incomplete!";
+            if tx <> rx then failwith "T13 error: tx <> rx!";
             a#close;
             b#close;
             listen#close
         with
         | Unix.Unix_error (e, fn, _) ->
-            failwith (Printf.sprintf "T12 error: %s in %s.\n"
+            failwith (Printf.sprintf "T13 error: %s in %s.\n"
                 (Unix.error_message e) fn)
 end
 
@@ -1356,7 +1356,7 @@ module T16 = struct
     
     class clock n dt =
         object
-            inherit [unit] time Cf_tai64n.last as super
+            inherit [unit Cf_poll.state_t] time Cf_tai64n.last as super
             
             val mutable count_: int = n
             
@@ -1364,7 +1364,7 @@ module T16 = struct
                 epoch_ <- Cf_tai64n.add (Cf_tai64n.now ()) dt;
                 super#load_ p
             
-            method private service_ p =
+            method private service p =
                 if count_ > 0 then begin
                     count_ <- pred count_;
                     epoch_ <- Cf_tai64n.add epoch_ dt;
@@ -1379,7 +1379,7 @@ module T16 = struct
     
     class interrupt n dt =
         object(self:'self)
-            inherit [int] signal Sys.sigint as super
+            inherit [int Cf_poll.state_t] signal Sys.sigint as super
 
             val clock_ = new clock n dt
             
@@ -1391,7 +1391,7 @@ module T16 = struct
                 super#unload_ p;
                 clock_#unload
             
-            method private service_ p =
+            method private service p =
                 clock_#unload;
                 `Final clock_#count
             
